# plan-b ![badge](https://badge.fury.io/rb/plan-b.svg)

A Jekyll based template for docs, resume, portfolio & etc.

[Demo website](https://salmanwaheed.github.io/plan-b/)

<img src="https://raw.githubusercontent.com/salmanwaheed/plan-b/master/screenshot.png" width="500">

## Installation

Simply fork the repository and edit away.

### Remote Development or Github Support:

- Create a `_config.yml` file.
- And just put `remote_theme: salmanwaheed/plan-b` in `_config.yml`.
- You are done :)

### Local Development:

```bash
# install jekyll theme
gem install plan-b

# your dir/site name
mkdir mysite && cd mysite

# Gemfile
cat > Gemfile <<-END
# frozen_string_literal: true

source "https://rubygems.org"

gem 'plan-b'
gem 'jemoji'
gem "jekyll"
gem "html-proofer"
END

# _config.yml
cat > _config.yml <<-END
theme: plan-b
remote_theme: salmanwaheed/plan-b # github support
END

# index.md
cat > index.md <<-END
---
layout: default
title: your page title
description: your short paragraph
---

# Your page content will be here, if you need any help please cantact to Salman Waheed by opening the issue
END

# Install Dummy content
mkdir _data && cd _data
curl -O https://github.com/salmanwaheed/plan-b/blob/master/_data/default.yml

# And then execute
bundle install

# use below command for local deployment
jekyll serve or bundle exec jekyll serve # open your browser at http://127.0.0.1:4000/
```

## You may have some issues / errors while setup or after installation

```bash
# If you get >>> jekyll 3.8.5 | Error:  Address already in use - bind(2) for 127.0.0.1:4000
lsof -wni tcp:4000 # try to find out PID

kill -9 YOUR-PID # lets kill PID

# If you get >>> You have already activated i18n 1.5.3, but your Gemfile requires i18n 0.9.5. Prepending `bundle exec` to your command may solve this. (Gem::LoadError)
sudo bundle clean --force # It removes every system gem not in this bundle

# If you get >>> can't find gem bundler (>= 0.a) with executable bundle (Gem::GemNotFoundException)
sudo gem install -n /usr/local/bin bundler
```

## Guidelines

You can check the [jekyll syntax](https://jekyllrb.com/docs/) from its official website

Easy to have file extensions: `.md or .html`

Each page must have front matter
```ruby
# index.md, about.md & etc
---
layout: default
title: your page title
paragraph: little bit about your current page
---

# _config.yml

#baseurl: "" # subdirs path e.g. /plan-b or /mysite
#url: "" # hostname e.g. https://salmanwaheed.github.io or https://127.0.0.1:4000

title: app name # site title
author: your name # author/developer name
email: your-email@gmail.com # author/developer email

lang: en-US
keywords: '' # seo keywords
description: # seo description

markdown: kramdown
# theme: plan-b # enable it, if you face any issue with local development
remote_theme: salmanwaheed/plan-b # for github support or remote development

favicon: '' # site icon
google_analytics: '#' # tracking code

header:
  container: true # show/hide header container
  navigation:
    - name: nav name
      link: 'url will be here'
      target: _blank
      .....

footer:
  container: true # show/hide footer container
  copyright: Design & Developed by
  navigation:
    - name: nav name
      link: 'url will be here'
      target: _blank
      .....
```

## License

The theme is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).
